### Discord
`https://discord.gg/7NmhxQBmET`
### About lib
`Fix Amino.fix and Amino.py 1.2.17`
### How to install?
`pip install servalfix`
### What is the Improvement that this library offers?
`Minor issues, and improvement for efficient use and/or faster use.`
### API Reference
[Read the Docs Link](https://aminopy.readthedocs.io/en/latest/)